package cn.iocoder.yudao.module.appBase.service.impl;

import cn.iocoder.yudao.module.appBase.entity.AppSwiper;
import cn.iocoder.yudao.module.appBase.service.IAppSwiperService;
import cn.iocoder.yudao.module.appBase.mapper.AppSwiperMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2023-08-01
 */
@Service
public class AppSwiperServiceImpl implements IAppSwiperService
{
    @Autowired
    private AppSwiperMapper appSwiperMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param swiperId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public AppSwiper selectAppSwiperBySwiperId(Long swiperId)
    {
        return appSwiperMapper.selectAppSwiperBySwiperId(swiperId);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appSwiper 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public IPage<AppSwiper> selectAppSwiperList(Page<AppSwiper> page, AppSwiper appSwiper)
    {
        return appSwiperMapper.selectAppSwiperList(page,appSwiper);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param appSwiper 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertAppSwiper(AppSwiper appSwiper)
    {
        return appSwiperMapper.insertAppSwiper(appSwiper);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param appSwiper 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateAppSwiper(AppSwiper appSwiper)
    {
        return appSwiperMapper.updateAppSwiper(appSwiper);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param swiperIds 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppSwiperBySwiperIds(Long[] swiperIds)
    {
        return appSwiperMapper.deleteAppSwiperBySwiperIds(swiperIds);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param swiperId 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppSwiperBySwiperId(Long swiperId)
    {
        return appSwiperMapper.deleteAppSwiperBySwiperId(swiperId);
    }
}
